@@ -1,10 +1,19 @@
+"""
+A substitute for the Python 3 open() function.
+
+Note that io.open() is more complete but maybe slower. Even so, the
+completeness may be a better default. TODO: compare these
+"""
+
+open_ = open
+
 class open(object):
     """Wrapper providing key part of Python 3 open() interface.
 
     From IPython's py3compat.py module. License: BSD.
     """
     def __init__(self, fname, mode="r", encoding="utf-8"):
-        self.f = orig_open(fname, mode)
+        self.f = open_(fname, mode)
         self.enc = encoding
 
     def write(self, s):
