@@ -4,7 +4,8 @@ the future module * imports.
 """
 
 from __future__ import absolute_import, division
-from future import int      # not long
+from future.builtins import int      # not long
+from future import utils
 
 import unittest
 
@@ -16,7 +17,8 @@ class TestBuiltins(unittest.TestCase):
     @unittest.expectedFailure   # Py2's long doesn't inherit from int!
     def test_long(self):
         self.assertEqual(isinstance(10**100, int))
-        self.assertEqual(isinstance(long(1), int))
+        if not utils.PY3:
+            self.assertEqual(isinstance(long(1), int))
         # Note: the following is a SyntaxError on Py3:
         # self.assertEqual(isinstance(1L, int))
 
