@@ -8,7 +8,7 @@ tests.
 
 from __future__ import (absolute_import, print_function, unicode_literals)
 from future import standard_library
-from future import *
+from future.builtins import *
 
 from test import support
 import pprint
