@@ -16,9 +16,10 @@ libfuturize_3fix_names = set([
                             # 'libfuturize.fixes3.fix_features',  # ?
                             'libfuturize.fixes3.fix_fullargspec',
                             # 'libfuturize.fixes3.fix_funcattrs',
+                            'libfuturize.fixes3.fix_future_builtins',   # adds "from future import *"
                             'libfuturize.fixes3.fix_getcwd',
-                            # 'libfuturize.fixes3.fix_imports',
-                            # 'libfuturize.fixes3.fix_imports2',
+                            'libfuturize.fixes3.fix_imports',   # adds "from future import standard_library"
+                            'libfuturize.fixes3.fix_imports2',
                             # 'libfuturize.fixes3.fix_input',
                             # 'libfuturize.fixes3.fix_int',
                             # 'libfuturize.fixes3.fix_intern',
@@ -28,7 +29,7 @@ libfuturize_3fix_names = set([
                             # 'libfuturize.fixes3.fix_metaclass',  # write a custom handler for
                             # this
                             # 'libfuturize.fixes3.fix_methodattrs',  # __func__ and __self__ seem to be defined on Py2.7 already
-                            'libfuturize.fixes3.fix_newstyle',   # yes, we want this. Without new-style classes in Py2, super() will break etc.
+                            'libfuturize.fixes3.fix_newstyle',   # yes, we want this: explicit inheritance from object. Without new-style classes in Py2, super() will break etc.
                             # 'libfuturize.fixes3.fix_next',   # use a decorator for this
                             # 'libfuturize.fixes3.fix_numliterals',   # prob not
                             # 'libfuturize.fixes3.fix_open',   # huh?
